cooperative Package
===================

:mod:`cooperative` Package
-----------------------------

.. automodule:: cooperative.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`_meta` Module
-------------------

.. automodule:: cooperative._meta
    :members:
    :undoc-members:
    :show-inheritance:


Subpackages
-----------

.. toctree::

    cooperative.tests
